@@ -80,6 +80,10 @@ class JAAQLController(BaseJAAQLController):
         def prepare(http_inputs: dict, account_id: str):
             return self.model.prepare_queries(http_inputs, account_id)
 
+        @self.publish_route('/domains', DOCUMENTATION__domains)
+        def prepare(http_inputs: dict, account_id: str):
+            return self.model.fetch_domains(http_inputs, account_id)
+
         @self.publish_route('/account/password', DOCUMENTATION__password)
         def password(account_id: str, username: str, ip_address: str, is_the_anonymous_user: bool, http_inputs: dict):
             return self.model.add_my_account_password(account_id, username, ip_address, is_the_anonymous_user, **http_inputs)
@@ -127,6 +131,13 @@ class JAAQLController(BaseJAAQLController):
         def cron(connection: DBInterface, http_inputs: dict):
             self.model.add_cron_job_to_application(connection, http_inputs)
 
+        @self.publish_route('/build-time', DOCUMENTATION__last_successful_build_timestamp)
+        def cron(http_inputs: dict):
+            if self.is_post():
+                self.model.set_last_successful_build_time(http_inputs)
+            else:
+                return self.model.get_last_successful_build_time()
+
         @self.publish_route('/webhook/<application>/<name>', DOCUMENTATION__webhook)
         def handle_webhook(application: str, name: str, body: bytes, headers: dict, args: dict, response: JAAQLResponse):
             self.model.handle_webhook(application, name, body, headers, args, response)
